==> haskell-sandwich-0.2.0.0-56-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sandwich.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sandwich
version:              0.2.0.0
visibility:           public
id:                   sandwich-0.2.0.0-LLCyc250tinKuuHCnE1oKM
key:                  sandwich-0.2.0.0-LLCyc250tinKuuHCnE1oKM
license:              BSD-3-Clause
copyright:            2023 Tom McLaughlin
maintainer:           tom@codedown.io
author:               Tom McLaughlin
homepage:             https://codedownio.github.io/sandwich
synopsis:             Yet another test framework for Haskell
description:
    Please see the <https://codedownio.github.io/sandwich documentation>.

category:             Testing
abi:                  9c38db37db7f08f4c12fcd2ae3ba07c4
exposed:              True
exposed-modules:
    Test.Sandwich Test.Sandwich.Contexts Test.Sandwich.Expectations
    Test.Sandwich.Formatters.FailureReport
    Test.Sandwich.Formatters.LogSaver Test.Sandwich.Formatters.Print
    Test.Sandwich.Formatters.Silent Test.Sandwich.Formatters.TerminalUI
    Test.Sandwich.Golden Test.Sandwich.Internal Test.Sandwich.Logging
    Test.Sandwich.Misc Test.Sandwich.Nodes Test.Sandwich.Options
    Test.Sandwich.TH

hidden-modules:
    Test.Sandwich.ArgParsing Test.Sandwich.Formatters.Common.Count
    Test.Sandwich.Formatters.Common.Util
    Test.Sandwich.Formatters.MarkdownSummary
    Test.Sandwich.Formatters.Print.CallStacks
    Test.Sandwich.Formatters.Print.Color
    Test.Sandwich.Formatters.Print.Common
    Test.Sandwich.Formatters.Print.FailureReason
    Test.Sandwich.Formatters.Print.Logs
    Test.Sandwich.Formatters.Print.Printing
    Test.Sandwich.Formatters.Print.PrintPretty
    Test.Sandwich.Formatters.Print.Types
    Test.Sandwich.Formatters.Print.Util
    Test.Sandwich.Formatters.TerminalUI.AttrMap
    Test.Sandwich.Formatters.TerminalUI.CrossPlatform
    Test.Sandwich.Formatters.TerminalUI.Draw
    Test.Sandwich.Formatters.TerminalUI.Draw.ColorProgressBar
    Test.Sandwich.Formatters.TerminalUI.Draw.RunTimes
    Test.Sandwich.Formatters.TerminalUI.Draw.ToBrickWidget
    Test.Sandwich.Formatters.TerminalUI.Draw.TopBox
    Test.Sandwich.Formatters.TerminalUI.Draw.Util
    Test.Sandwich.Formatters.TerminalUI.Filter
    Test.Sandwich.Formatters.TerminalUI.Keys
    Test.Sandwich.Formatters.TerminalUI.OpenInEditor
    Test.Sandwich.Formatters.TerminalUI.Types
    Test.Sandwich.Golden.Update Test.Sandwich.Internal.Formatters
    Test.Sandwich.Internal.Running
    Test.Sandwich.Interpreters.FilterTree
    Test.Sandwich.Interpreters.FilterTreeModule
    Test.Sandwich.Interpreters.PrettyShow
    Test.Sandwich.Interpreters.PruneTree
    Test.Sandwich.Interpreters.RunTree
    Test.Sandwich.Interpreters.RunTree.Logging
    Test.Sandwich.Interpreters.RunTree.Util
    Test.Sandwich.Interpreters.StartTree Test.Sandwich.ParallelN
    Test.Sandwich.RunTree Test.Sandwich.Shutdown Test.Sandwich.Signals
    Test.Sandwich.TestTimer Test.Sandwich.TH.HasMainFunction
    Test.Sandwich.TH.ModuleMap Test.Sandwich.Types.ArgParsing
    Test.Sandwich.Types.General Test.Sandwich.Types.RunTree
    Test.Sandwich.Types.Spec Test.Sandwich.Types.TestTimer
    Test.Sandwich.Types.TestTimer.LensRules Test.Sandwich.Util
    Paths_sandwich

import-dirs:          /usr/lib/ghc-9.4.8/site-local/sandwich-0.2.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/sandwich-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/sandwich-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sandwich
hs-libraries:         HSsandwich-0.2.0.0-LLCyc250tinKuuHCnE1oKM
depends:
    aeson-2.1.2.1-J19dEw13kUOF5hLEOQVj2r
    ansi-terminal-1.0.2-ELflFHQZXI14MtzKLMv1G6
    async-2.2.5-BcqMz9kSLpQJiwvDzQjiwa base-4.17.2.1
    brick-2.2-7tUchDWF0bNLYIwwNr824C bytestring-0.11.5.3
    colour-2.3.6-7P0PYboBVJiKAHuC03TfZO containers-0.6.7
    deepseq-1.4.8.0 directory-1.3.7.1 exceptions-0.10.5
    filepath-1.4.2.2 free-5.2-3rsNvYqTHxIBI27gtRd9G
    haskell-src-exts-1.23.1-8YCvwGoz5v65yIba8GoVHN
    lifted-async-0.10.2.7-3AsLq5PIIUJ6Hghjbh7UYv
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt
    microlens-th-0.4.3.17-GRXwDxs8Aw09PQskuAg669
    monad-control-1.0.3.1-A6UHjJX2HGtJRyc7xUQpzx
    monad-logger-0.3.42-y59qaH1kZAAtHXpRtTu7V mtl-2.2.2
    optparse-applicative-0.18.1.0-FoUSxzMBUR5IeTMTUEotqz
    pretty-show-1.10-Ey6CADemQl3EFi7OIHqHDp process-1.6.18.0
    safe-0.3.21-BTgY19Ix98PEQ0IXGyRX6s
    safe-exceptions-0.1.7.4-ExCGuwbaU3IIG6Rbj40P0X stm-2.5.1.0
    string-interpolate-0.3.4.0-5EvjHXflWHACx88jigdjQg
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    transformers-0.5.6.2 transformers-base-0.4.6-7kB1pwF0Wr6CXgFXZQ42bw
    unix-2.7.3 unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    vector-0.13.2.0-FNdsFzivQrc5gVfjRMxS7n
    vty-6.2-FRnfDo2xxnWL0uInxiUZOM
    vty-crossplatform-0.4.0.0-FNwk96wgCrW1wqnOiHKuJf

haddock-interfaces:   /usr/share/doc/haskell-sandwich/html/sandwich.haddock
haddock-html:         /usr/share/doc/haskell-sandwich/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sandwich-0.2.0.0-57-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sandwich.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sandwich
version:              0.2.0.0
visibility:           public
id:                   sandwich-0.2.0.0-AILVxSMifdSH79UNc9KpB9
key:                  sandwich-0.2.0.0-AILVxSMifdSH79UNc9KpB9
license:              BSD-3-Clause
copyright:            2023 Tom McLaughlin
maintainer:           tom@codedown.io
author:               Tom McLaughlin
homepage:             https://codedownio.github.io/sandwich
synopsis:             Yet another test framework for Haskell
description:
    Please see the <https://codedownio.github.io/sandwich documentation>.

category:             Testing
abi:                  9366e5293b6507380f3e78f6e0041d55
exposed:              True
exposed-modules:
    Test.Sandwich Test.Sandwich.Contexts Test.Sandwich.Expectations
    Test.Sandwich.Formatters.FailureReport
    Test.Sandwich.Formatters.LogSaver Test.Sandwich.Formatters.Print
    Test.Sandwich.Formatters.Silent Test.Sandwich.Formatters.TerminalUI
    Test.Sandwich.Golden Test.Sandwich.Internal Test.Sandwich.Logging
    Test.Sandwich.Misc Test.Sandwich.Nodes Test.Sandwich.Options
    Test.Sandwich.TH

hidden-modules:
    Test.Sandwich.ArgParsing Test.Sandwich.Formatters.Common.Count
    Test.Sandwich.Formatters.Common.Util
    Test.Sandwich.Formatters.MarkdownSummary
    Test.Sandwich.Formatters.Print.CallStacks
    Test.Sandwich.Formatters.Print.Color
    Test.Sandwich.Formatters.Print.Common
    Test.Sandwich.Formatters.Print.FailureReason
    Test.Sandwich.Formatters.Print.Logs
    Test.Sandwich.Formatters.Print.Printing
    Test.Sandwich.Formatters.Print.PrintPretty
    Test.Sandwich.Formatters.Print.Types
    Test.Sandwich.Formatters.Print.Util
    Test.Sandwich.Formatters.TerminalUI.AttrMap
    Test.Sandwich.Formatters.TerminalUI.CrossPlatform
    Test.Sandwich.Formatters.TerminalUI.Draw
    Test.Sandwich.Formatters.TerminalUI.Draw.ColorProgressBar
    Test.Sandwich.Formatters.TerminalUI.Draw.RunTimes
    Test.Sandwich.Formatters.TerminalUI.Draw.ToBrickWidget
    Test.Sandwich.Formatters.TerminalUI.Draw.TopBox
    Test.Sandwich.Formatters.TerminalUI.Draw.Util
    Test.Sandwich.Formatters.TerminalUI.Filter
    Test.Sandwich.Formatters.TerminalUI.Keys
    Test.Sandwich.Formatters.TerminalUI.OpenInEditor
    Test.Sandwich.Formatters.TerminalUI.Types
    Test.Sandwich.Golden.Update Test.Sandwich.Internal.Formatters
    Test.Sandwich.Internal.Running
    Test.Sandwich.Interpreters.FilterTree
    Test.Sandwich.Interpreters.FilterTreeModule
    Test.Sandwich.Interpreters.PrettyShow
    Test.Sandwich.Interpreters.PruneTree
    Test.Sandwich.Interpreters.RunTree
    Test.Sandwich.Interpreters.RunTree.Logging
    Test.Sandwich.Interpreters.RunTree.Util
    Test.Sandwich.Interpreters.StartTree Test.Sandwich.ParallelN
    Test.Sandwich.RunTree Test.Sandwich.Shutdown Test.Sandwich.Signals
    Test.Sandwich.TestTimer Test.Sandwich.TH.HasMainFunction
    Test.Sandwich.TH.ModuleMap Test.Sandwich.Types.ArgParsing
    Test.Sandwich.Types.General Test.Sandwich.Types.RunTree
    Test.Sandwich.Types.Spec Test.Sandwich.Types.TestTimer
    Test.Sandwich.Types.TestTimer.LensRules Test.Sandwich.Util
    Paths_sandwich

import-dirs:          /usr/lib/ghc-9.4.8/site-local/sandwich-0.2.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/sandwich-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/sandwich-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sandwich
hs-libraries:         HSsandwich-0.2.0.0-AILVxSMifdSH79UNc9KpB9
depends:
    aeson-2.1.2.1-wY4CXNP4Ti6TCaMY1tyMf
    ansi-terminal-1.0.2-JhmKbae07oX7bHm2tOBr0F
    async-2.2.5-HgJvyv8nLlGBOZUsxEMYyx base-4.17.2.1
    brick-2.2-1KVDaH8QWh7JfvCnHIFONM bytestring-0.11.5.3
    colour-2.3.6-5kduP8EJo8q50TTkpFMjx8 containers-0.6.7
    deepseq-1.4.8.0 directory-1.3.7.1 exceptions-0.10.5
    filepath-1.4.2.2 free-5.2-ERbQ4KpKIFl9MlA7wUwsjS
    haskell-src-exts-1.23.1-6lePEDtRHy8J6JhqOxjATA
    lifted-async-0.10.2.7-BegutvSj3nNKvVpgUb4Uux
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt
    microlens-th-0.4.3.17-GRXwDxs8Aw09PQskuAg669
    monad-control-1.0.3.1-5MkAM4FLEyHGYqORCXEDzl
    monad-logger-0.3.42-KfaLqpFGTiT89GbXnfnuZQ mtl-2.2.2
    optparse-applicative-0.18.1.0-ImNwmQfwdUdQZElVvxe6u
    pretty-show-1.10-Ey6CADemQl3EFi7OIHqHDp process-1.6.18.0
    safe-0.3.21-8UNW4gIoNRmKgGFufdPOla
    safe-exceptions-0.1.7.4-2Rld96PQeHNLphPII72qvg stm-2.5.1.0
    string-interpolate-0.3.4.0-EHxenN3YXSHBHlDAO8AdqP
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    transformers-0.5.6.2 transformers-base-0.4.6-Hst2ZvVN1773HZEalQop5t
    unix-2.7.3 unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    vector-0.13.2.0-B5pfN7kp2sVHpMWItbJQ58
    vty-6.2-3JAQfV88tluAzVgT4ckUaK
    vty-crossplatform-0.4.0.0-GzdjDja9WsB1vNb92p1S69

haddock-interfaces:   /usr/share/doc/haskell-sandwich/html/sandwich.haddock
haddock-html:         /usr/share/doc/haskell-sandwich/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
